# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class MediaSourceInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chapters': 'list[ChapterInfo]',
        'protocol': 'MediaProtocol',
        'id': 'str',
        'path': 'str',
        'encoder_path': 'str',
        'encoder_protocol': 'MediaProtocol',
        'type': 'MediaSourceType',
        'probe_path': 'str',
        'probe_protocol': 'MediaProtocol',
        'container': 'str',
        'size': 'int',
        'name': 'str',
        'sort_name': 'str',
        'is_remote': 'bool',
        'has_mixed_protocols': 'bool',
        'run_time_ticks': 'int',
        'container_start_time_ticks': 'int',
        'supports_transcoding': 'bool',
        'trancode_live_start_index': 'int',
        'wall_clock_start': 'datetime',
        'supports_direct_stream': 'bool',
        'supports_direct_play': 'bool',
        'is_infinite_stream': 'bool',
        'requires_opening': 'bool',
        'open_token': 'str',
        'requires_closing': 'bool',
        'live_stream_id': 'str',
        'buffer_ms': 'int',
        'requires_looping': 'bool',
        'supports_probing': 'bool',
        'video3_d_format': 'Video3DFormat',
        'media_streams': 'list[MediaStream]',
        'formats': 'list[str]',
        'bitrate': 'int',
        'timestamp': 'TransportStreamTimestamp',
        'required_http_headers': 'dict(str, str)',
        'direct_stream_url': 'str',
        'add_api_key_to_direct_stream_url': 'bool',
        'transcoding_url': 'str',
        'transcoding_sub_protocol': 'str',
        'transcoding_container': 'str',
        'analyze_duration_ms': 'int',
        'read_at_native_framerate': 'bool',
        'default_audio_stream_index': 'int',
        'default_subtitle_stream_index': 'int',
        'item_id': 'str',
        'server_id': 'str'
    }

    attribute_map = {
        'chapters': 'Chapters',
        'protocol': 'Protocol',
        'id': 'Id',
        'path': 'Path',
        'encoder_path': 'EncoderPath',
        'encoder_protocol': 'EncoderProtocol',
        'type': 'Type',
        'probe_path': 'ProbePath',
        'probe_protocol': 'ProbeProtocol',
        'container': 'Container',
        'size': 'Size',
        'name': 'Name',
        'sort_name': 'SortName',
        'is_remote': 'IsRemote',
        'has_mixed_protocols': 'HasMixedProtocols',
        'run_time_ticks': 'RunTimeTicks',
        'container_start_time_ticks': 'ContainerStartTimeTicks',
        'supports_transcoding': 'SupportsTranscoding',
        'trancode_live_start_index': 'TrancodeLiveStartIndex',
        'wall_clock_start': 'WallClockStart',
        'supports_direct_stream': 'SupportsDirectStream',
        'supports_direct_play': 'SupportsDirectPlay',
        'is_infinite_stream': 'IsInfiniteStream',
        'requires_opening': 'RequiresOpening',
        'open_token': 'OpenToken',
        'requires_closing': 'RequiresClosing',
        'live_stream_id': 'LiveStreamId',
        'buffer_ms': 'BufferMs',
        'requires_looping': 'RequiresLooping',
        'supports_probing': 'SupportsProbing',
        'video3_d_format': 'Video3DFormat',
        'media_streams': 'MediaStreams',
        'formats': 'Formats',
        'bitrate': 'Bitrate',
        'timestamp': 'Timestamp',
        'required_http_headers': 'RequiredHttpHeaders',
        'direct_stream_url': 'DirectStreamUrl',
        'add_api_key_to_direct_stream_url': 'AddApiKeyToDirectStreamUrl',
        'transcoding_url': 'TranscodingUrl',
        'transcoding_sub_protocol': 'TranscodingSubProtocol',
        'transcoding_container': 'TranscodingContainer',
        'analyze_duration_ms': 'AnalyzeDurationMs',
        'read_at_native_framerate': 'ReadAtNativeFramerate',
        'default_audio_stream_index': 'DefaultAudioStreamIndex',
        'default_subtitle_stream_index': 'DefaultSubtitleStreamIndex',
        'item_id': 'ItemId',
        'server_id': 'ServerId'
    }

    def __init__(self, chapters=None, protocol=None, id=None, path=None, encoder_path=None, encoder_protocol=None, type=None, probe_path=None, probe_protocol=None, container=None, size=None, name=None, sort_name=None, is_remote=None, has_mixed_protocols=None, run_time_ticks=None, container_start_time_ticks=None, supports_transcoding=None, trancode_live_start_index=None, wall_clock_start=None, supports_direct_stream=None, supports_direct_play=None, is_infinite_stream=None, requires_opening=None, open_token=None, requires_closing=None, live_stream_id=None, buffer_ms=None, requires_looping=None, supports_probing=None, video3_d_format=None, media_streams=None, formats=None, bitrate=None, timestamp=None, required_http_headers=None, direct_stream_url=None, add_api_key_to_direct_stream_url=None, transcoding_url=None, transcoding_sub_protocol=None, transcoding_container=None, analyze_duration_ms=None, read_at_native_framerate=None, default_audio_stream_index=None, default_subtitle_stream_index=None, item_id=None, server_id=None):  # noqa: E501
        """MediaSourceInfo - a model defined in Swagger"""  # noqa: E501
        self._chapters = None
        self._protocol = None
        self._id = None
        self._path = None
        self._encoder_path = None
        self._encoder_protocol = None
        self._type = None
        self._probe_path = None
        self._probe_protocol = None
        self._container = None
        self._size = None
        self._name = None
        self._sort_name = None
        self._is_remote = None
        self._has_mixed_protocols = None
        self._run_time_ticks = None
        self._container_start_time_ticks = None
        self._supports_transcoding = None
        self._trancode_live_start_index = None
        self._wall_clock_start = None
        self._supports_direct_stream = None
        self._supports_direct_play = None
        self._is_infinite_stream = None
        self._requires_opening = None
        self._open_token = None
        self._requires_closing = None
        self._live_stream_id = None
        self._buffer_ms = None
        self._requires_looping = None
        self._supports_probing = None
        self._video3_d_format = None
        self._media_streams = None
        self._formats = None
        self._bitrate = None
        self._timestamp = None
        self._required_http_headers = None
        self._direct_stream_url = None
        self._add_api_key_to_direct_stream_url = None
        self._transcoding_url = None
        self._transcoding_sub_protocol = None
        self._transcoding_container = None
        self._analyze_duration_ms = None
        self._read_at_native_framerate = None
        self._default_audio_stream_index = None
        self._default_subtitle_stream_index = None
        self._item_id = None
        self._server_id = None
        self.discriminator = None
        if chapters is not None:
            self.chapters = chapters
        if protocol is not None:
            self.protocol = protocol
        if id is not None:
            self.id = id
        if path is not None:
            self.path = path
        if encoder_path is not None:
            self.encoder_path = encoder_path
        if encoder_protocol is not None:
            self.encoder_protocol = encoder_protocol
        if type is not None:
            self.type = type
        if probe_path is not None:
            self.probe_path = probe_path
        if probe_protocol is not None:
            self.probe_protocol = probe_protocol
        if container is not None:
            self.container = container
        if size is not None:
            self.size = size
        if name is not None:
            self.name = name
        if sort_name is not None:
            self.sort_name = sort_name
        if is_remote is not None:
            self.is_remote = is_remote
        if has_mixed_protocols is not None:
            self.has_mixed_protocols = has_mixed_protocols
        if run_time_ticks is not None:
            self.run_time_ticks = run_time_ticks
        if container_start_time_ticks is not None:
            self.container_start_time_ticks = container_start_time_ticks
        if supports_transcoding is not None:
            self.supports_transcoding = supports_transcoding
        if trancode_live_start_index is not None:
            self.trancode_live_start_index = trancode_live_start_index
        if wall_clock_start is not None:
            self.wall_clock_start = wall_clock_start
        if supports_direct_stream is not None:
            self.supports_direct_stream = supports_direct_stream
        if supports_direct_play is not None:
            self.supports_direct_play = supports_direct_play
        if is_infinite_stream is not None:
            self.is_infinite_stream = is_infinite_stream
        if requires_opening is not None:
            self.requires_opening = requires_opening
        if open_token is not None:
            self.open_token = open_token
        if requires_closing is not None:
            self.requires_closing = requires_closing
        if live_stream_id is not None:
            self.live_stream_id = live_stream_id
        if buffer_ms is not None:
            self.buffer_ms = buffer_ms
        if requires_looping is not None:
            self.requires_looping = requires_looping
        if supports_probing is not None:
            self.supports_probing = supports_probing
        if video3_d_format is not None:
            self.video3_d_format = video3_d_format
        if media_streams is not None:
            self.media_streams = media_streams
        if formats is not None:
            self.formats = formats
        if bitrate is not None:
            self.bitrate = bitrate
        if timestamp is not None:
            self.timestamp = timestamp
        if required_http_headers is not None:
            self.required_http_headers = required_http_headers
        if direct_stream_url is not None:
            self.direct_stream_url = direct_stream_url
        if add_api_key_to_direct_stream_url is not None:
            self.add_api_key_to_direct_stream_url = add_api_key_to_direct_stream_url
        if transcoding_url is not None:
            self.transcoding_url = transcoding_url
        if transcoding_sub_protocol is not None:
            self.transcoding_sub_protocol = transcoding_sub_protocol
        if transcoding_container is not None:
            self.transcoding_container = transcoding_container
        if analyze_duration_ms is not None:
            self.analyze_duration_ms = analyze_duration_ms
        if read_at_native_framerate is not None:
            self.read_at_native_framerate = read_at_native_framerate
        if default_audio_stream_index is not None:
            self.default_audio_stream_index = default_audio_stream_index
        if default_subtitle_stream_index is not None:
            self.default_subtitle_stream_index = default_subtitle_stream_index
        if item_id is not None:
            self.item_id = item_id
        if server_id is not None:
            self.server_id = server_id

    @property
    def chapters(self):
        """Gets the chapters of this MediaSourceInfo.  # noqa: E501


        :return: The chapters of this MediaSourceInfo.  # noqa: E501
        :rtype: list[ChapterInfo]
        """
        return self._chapters

    @chapters.setter
    def chapters(self, chapters):
        """Sets the chapters of this MediaSourceInfo.


        :param chapters: The chapters of this MediaSourceInfo.  # noqa: E501
        :type: list[ChapterInfo]
        """

        self._chapters = chapters

    @property
    def protocol(self):
        """Gets the protocol of this MediaSourceInfo.  # noqa: E501


        :return: The protocol of this MediaSourceInfo.  # noqa: E501
        :rtype: MediaProtocol
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this MediaSourceInfo.


        :param protocol: The protocol of this MediaSourceInfo.  # noqa: E501
        :type: MediaProtocol
        """

        self._protocol = protocol

    @property
    def id(self):
        """Gets the id of this MediaSourceInfo.  # noqa: E501


        :return: The id of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MediaSourceInfo.


        :param id: The id of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def path(self):
        """Gets the path of this MediaSourceInfo.  # noqa: E501


        :return: The path of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this MediaSourceInfo.


        :param path: The path of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def encoder_path(self):
        """Gets the encoder_path of this MediaSourceInfo.  # noqa: E501


        :return: The encoder_path of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._encoder_path

    @encoder_path.setter
    def encoder_path(self, encoder_path):
        """Sets the encoder_path of this MediaSourceInfo.


        :param encoder_path: The encoder_path of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._encoder_path = encoder_path

    @property
    def encoder_protocol(self):
        """Gets the encoder_protocol of this MediaSourceInfo.  # noqa: E501


        :return: The encoder_protocol of this MediaSourceInfo.  # noqa: E501
        :rtype: MediaProtocol
        """
        return self._encoder_protocol

    @encoder_protocol.setter
    def encoder_protocol(self, encoder_protocol):
        """Sets the encoder_protocol of this MediaSourceInfo.


        :param encoder_protocol: The encoder_protocol of this MediaSourceInfo.  # noqa: E501
        :type: MediaProtocol
        """

        self._encoder_protocol = encoder_protocol

    @property
    def type(self):
        """Gets the type of this MediaSourceInfo.  # noqa: E501


        :return: The type of this MediaSourceInfo.  # noqa: E501
        :rtype: MediaSourceType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MediaSourceInfo.


        :param type: The type of this MediaSourceInfo.  # noqa: E501
        :type: MediaSourceType
        """

        self._type = type

    @property
    def probe_path(self):
        """Gets the probe_path of this MediaSourceInfo.  # noqa: E501


        :return: The probe_path of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._probe_path

    @probe_path.setter
    def probe_path(self, probe_path):
        """Sets the probe_path of this MediaSourceInfo.


        :param probe_path: The probe_path of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._probe_path = probe_path

    @property
    def probe_protocol(self):
        """Gets the probe_protocol of this MediaSourceInfo.  # noqa: E501


        :return: The probe_protocol of this MediaSourceInfo.  # noqa: E501
        :rtype: MediaProtocol
        """
        return self._probe_protocol

    @probe_protocol.setter
    def probe_protocol(self, probe_protocol):
        """Sets the probe_protocol of this MediaSourceInfo.


        :param probe_protocol: The probe_protocol of this MediaSourceInfo.  # noqa: E501
        :type: MediaProtocol
        """

        self._probe_protocol = probe_protocol

    @property
    def container(self):
        """Gets the container of this MediaSourceInfo.  # noqa: E501


        :return: The container of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this MediaSourceInfo.


        :param container: The container of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._container = container

    @property
    def size(self):
        """Gets the size of this MediaSourceInfo.  # noqa: E501


        :return: The size of this MediaSourceInfo.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this MediaSourceInfo.


        :param size: The size of this MediaSourceInfo.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def name(self):
        """Gets the name of this MediaSourceInfo.  # noqa: E501


        :return: The name of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MediaSourceInfo.


        :param name: The name of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def sort_name(self):
        """Gets the sort_name of this MediaSourceInfo.  # noqa: E501


        :return: The sort_name of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._sort_name

    @sort_name.setter
    def sort_name(self, sort_name):
        """Sets the sort_name of this MediaSourceInfo.


        :param sort_name: The sort_name of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._sort_name = sort_name

    @property
    def is_remote(self):
        """Gets the is_remote of this MediaSourceInfo.  # noqa: E501

        Differentiate internet url vs local network  # noqa: E501

        :return: The is_remote of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_remote

    @is_remote.setter
    def is_remote(self, is_remote):
        """Sets the is_remote of this MediaSourceInfo.

        Differentiate internet url vs local network  # noqa: E501

        :param is_remote: The is_remote of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._is_remote = is_remote

    @property
    def has_mixed_protocols(self):
        """Gets the has_mixed_protocols of this MediaSourceInfo.  # noqa: E501


        :return: The has_mixed_protocols of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_mixed_protocols

    @has_mixed_protocols.setter
    def has_mixed_protocols(self, has_mixed_protocols):
        """Sets the has_mixed_protocols of this MediaSourceInfo.


        :param has_mixed_protocols: The has_mixed_protocols of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._has_mixed_protocols = has_mixed_protocols

    @property
    def run_time_ticks(self):
        """Gets the run_time_ticks of this MediaSourceInfo.  # noqa: E501


        :return: The run_time_ticks of this MediaSourceInfo.  # noqa: E501
        :rtype: int
        """
        return self._run_time_ticks

    @run_time_ticks.setter
    def run_time_ticks(self, run_time_ticks):
        """Sets the run_time_ticks of this MediaSourceInfo.


        :param run_time_ticks: The run_time_ticks of this MediaSourceInfo.  # noqa: E501
        :type: int
        """

        self._run_time_ticks = run_time_ticks

    @property
    def container_start_time_ticks(self):
        """Gets the container_start_time_ticks of this MediaSourceInfo.  # noqa: E501


        :return: The container_start_time_ticks of this MediaSourceInfo.  # noqa: E501
        :rtype: int
        """
        return self._container_start_time_ticks

    @container_start_time_ticks.setter
    def container_start_time_ticks(self, container_start_time_ticks):
        """Sets the container_start_time_ticks of this MediaSourceInfo.


        :param container_start_time_ticks: The container_start_time_ticks of this MediaSourceInfo.  # noqa: E501
        :type: int
        """

        self._container_start_time_ticks = container_start_time_ticks

    @property
    def supports_transcoding(self):
        """Gets the supports_transcoding of this MediaSourceInfo.  # noqa: E501


        :return: The supports_transcoding of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supports_transcoding

    @supports_transcoding.setter
    def supports_transcoding(self, supports_transcoding):
        """Sets the supports_transcoding of this MediaSourceInfo.


        :param supports_transcoding: The supports_transcoding of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._supports_transcoding = supports_transcoding

    @property
    def trancode_live_start_index(self):
        """Gets the trancode_live_start_index of this MediaSourceInfo.  # noqa: E501


        :return: The trancode_live_start_index of this MediaSourceInfo.  # noqa: E501
        :rtype: int
        """
        return self._trancode_live_start_index

    @trancode_live_start_index.setter
    def trancode_live_start_index(self, trancode_live_start_index):
        """Sets the trancode_live_start_index of this MediaSourceInfo.


        :param trancode_live_start_index: The trancode_live_start_index of this MediaSourceInfo.  # noqa: E501
        :type: int
        """

        self._trancode_live_start_index = trancode_live_start_index

    @property
    def wall_clock_start(self):
        """Gets the wall_clock_start of this MediaSourceInfo.  # noqa: E501


        :return: The wall_clock_start of this MediaSourceInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._wall_clock_start

    @wall_clock_start.setter
    def wall_clock_start(self, wall_clock_start):
        """Sets the wall_clock_start of this MediaSourceInfo.


        :param wall_clock_start: The wall_clock_start of this MediaSourceInfo.  # noqa: E501
        :type: datetime
        """

        self._wall_clock_start = wall_clock_start

    @property
    def supports_direct_stream(self):
        """Gets the supports_direct_stream of this MediaSourceInfo.  # noqa: E501


        :return: The supports_direct_stream of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supports_direct_stream

    @supports_direct_stream.setter
    def supports_direct_stream(self, supports_direct_stream):
        """Sets the supports_direct_stream of this MediaSourceInfo.


        :param supports_direct_stream: The supports_direct_stream of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._supports_direct_stream = supports_direct_stream

    @property
    def supports_direct_play(self):
        """Gets the supports_direct_play of this MediaSourceInfo.  # noqa: E501


        :return: The supports_direct_play of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supports_direct_play

    @supports_direct_play.setter
    def supports_direct_play(self, supports_direct_play):
        """Sets the supports_direct_play of this MediaSourceInfo.


        :param supports_direct_play: The supports_direct_play of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._supports_direct_play = supports_direct_play

    @property
    def is_infinite_stream(self):
        """Gets the is_infinite_stream of this MediaSourceInfo.  # noqa: E501


        :return: The is_infinite_stream of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_infinite_stream

    @is_infinite_stream.setter
    def is_infinite_stream(self, is_infinite_stream):
        """Sets the is_infinite_stream of this MediaSourceInfo.


        :param is_infinite_stream: The is_infinite_stream of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._is_infinite_stream = is_infinite_stream

    @property
    def requires_opening(self):
        """Gets the requires_opening of this MediaSourceInfo.  # noqa: E501


        :return: The requires_opening of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._requires_opening

    @requires_opening.setter
    def requires_opening(self, requires_opening):
        """Sets the requires_opening of this MediaSourceInfo.


        :param requires_opening: The requires_opening of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._requires_opening = requires_opening

    @property
    def open_token(self):
        """Gets the open_token of this MediaSourceInfo.  # noqa: E501


        :return: The open_token of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._open_token

    @open_token.setter
    def open_token(self, open_token):
        """Sets the open_token of this MediaSourceInfo.


        :param open_token: The open_token of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._open_token = open_token

    @property
    def requires_closing(self):
        """Gets the requires_closing of this MediaSourceInfo.  # noqa: E501


        :return: The requires_closing of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._requires_closing

    @requires_closing.setter
    def requires_closing(self, requires_closing):
        """Sets the requires_closing of this MediaSourceInfo.


        :param requires_closing: The requires_closing of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._requires_closing = requires_closing

    @property
    def live_stream_id(self):
        """Gets the live_stream_id of this MediaSourceInfo.  # noqa: E501


        :return: The live_stream_id of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._live_stream_id

    @live_stream_id.setter
    def live_stream_id(self, live_stream_id):
        """Sets the live_stream_id of this MediaSourceInfo.


        :param live_stream_id: The live_stream_id of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._live_stream_id = live_stream_id

    @property
    def buffer_ms(self):
        """Gets the buffer_ms of this MediaSourceInfo.  # noqa: E501


        :return: The buffer_ms of this MediaSourceInfo.  # noqa: E501
        :rtype: int
        """
        return self._buffer_ms

    @buffer_ms.setter
    def buffer_ms(self, buffer_ms):
        """Sets the buffer_ms of this MediaSourceInfo.


        :param buffer_ms: The buffer_ms of this MediaSourceInfo.  # noqa: E501
        :type: int
        """

        self._buffer_ms = buffer_ms

    @property
    def requires_looping(self):
        """Gets the requires_looping of this MediaSourceInfo.  # noqa: E501


        :return: The requires_looping of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._requires_looping

    @requires_looping.setter
    def requires_looping(self, requires_looping):
        """Sets the requires_looping of this MediaSourceInfo.


        :param requires_looping: The requires_looping of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._requires_looping = requires_looping

    @property
    def supports_probing(self):
        """Gets the supports_probing of this MediaSourceInfo.  # noqa: E501


        :return: The supports_probing of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supports_probing

    @supports_probing.setter
    def supports_probing(self, supports_probing):
        """Sets the supports_probing of this MediaSourceInfo.


        :param supports_probing: The supports_probing of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._supports_probing = supports_probing

    @property
    def video3_d_format(self):
        """Gets the video3_d_format of this MediaSourceInfo.  # noqa: E501


        :return: The video3_d_format of this MediaSourceInfo.  # noqa: E501
        :rtype: Video3DFormat
        """
        return self._video3_d_format

    @video3_d_format.setter
    def video3_d_format(self, video3_d_format):
        """Sets the video3_d_format of this MediaSourceInfo.


        :param video3_d_format: The video3_d_format of this MediaSourceInfo.  # noqa: E501
        :type: Video3DFormat
        """

        self._video3_d_format = video3_d_format

    @property
    def media_streams(self):
        """Gets the media_streams of this MediaSourceInfo.  # noqa: E501


        :return: The media_streams of this MediaSourceInfo.  # noqa: E501
        :rtype: list[MediaStream]
        """
        return self._media_streams

    @media_streams.setter
    def media_streams(self, media_streams):
        """Sets the media_streams of this MediaSourceInfo.


        :param media_streams: The media_streams of this MediaSourceInfo.  # noqa: E501
        :type: list[MediaStream]
        """

        self._media_streams = media_streams

    @property
    def formats(self):
        """Gets the formats of this MediaSourceInfo.  # noqa: E501


        :return: The formats of this MediaSourceInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._formats

    @formats.setter
    def formats(self, formats):
        """Sets the formats of this MediaSourceInfo.


        :param formats: The formats of this MediaSourceInfo.  # noqa: E501
        :type: list[str]
        """

        self._formats = formats

    @property
    def bitrate(self):
        """Gets the bitrate of this MediaSourceInfo.  # noqa: E501


        :return: The bitrate of this MediaSourceInfo.  # noqa: E501
        :rtype: int
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        """Sets the bitrate of this MediaSourceInfo.


        :param bitrate: The bitrate of this MediaSourceInfo.  # noqa: E501
        :type: int
        """

        self._bitrate = bitrate

    @property
    def timestamp(self):
        """Gets the timestamp of this MediaSourceInfo.  # noqa: E501


        :return: The timestamp of this MediaSourceInfo.  # noqa: E501
        :rtype: TransportStreamTimestamp
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this MediaSourceInfo.


        :param timestamp: The timestamp of this MediaSourceInfo.  # noqa: E501
        :type: TransportStreamTimestamp
        """

        self._timestamp = timestamp

    @property
    def required_http_headers(self):
        """Gets the required_http_headers of this MediaSourceInfo.  # noqa: E501


        :return: The required_http_headers of this MediaSourceInfo.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._required_http_headers

    @required_http_headers.setter
    def required_http_headers(self, required_http_headers):
        """Sets the required_http_headers of this MediaSourceInfo.


        :param required_http_headers: The required_http_headers of this MediaSourceInfo.  # noqa: E501
        :type: dict(str, str)
        """

        self._required_http_headers = required_http_headers

    @property
    def direct_stream_url(self):
        """Gets the direct_stream_url of this MediaSourceInfo.  # noqa: E501


        :return: The direct_stream_url of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._direct_stream_url

    @direct_stream_url.setter
    def direct_stream_url(self, direct_stream_url):
        """Sets the direct_stream_url of this MediaSourceInfo.


        :param direct_stream_url: The direct_stream_url of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._direct_stream_url = direct_stream_url

    @property
    def add_api_key_to_direct_stream_url(self):
        """Gets the add_api_key_to_direct_stream_url of this MediaSourceInfo.  # noqa: E501


        :return: The add_api_key_to_direct_stream_url of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._add_api_key_to_direct_stream_url

    @add_api_key_to_direct_stream_url.setter
    def add_api_key_to_direct_stream_url(self, add_api_key_to_direct_stream_url):
        """Sets the add_api_key_to_direct_stream_url of this MediaSourceInfo.


        :param add_api_key_to_direct_stream_url: The add_api_key_to_direct_stream_url of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._add_api_key_to_direct_stream_url = add_api_key_to_direct_stream_url

    @property
    def transcoding_url(self):
        """Gets the transcoding_url of this MediaSourceInfo.  # noqa: E501


        :return: The transcoding_url of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._transcoding_url

    @transcoding_url.setter
    def transcoding_url(self, transcoding_url):
        """Sets the transcoding_url of this MediaSourceInfo.


        :param transcoding_url: The transcoding_url of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._transcoding_url = transcoding_url

    @property
    def transcoding_sub_protocol(self):
        """Gets the transcoding_sub_protocol of this MediaSourceInfo.  # noqa: E501


        :return: The transcoding_sub_protocol of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._transcoding_sub_protocol

    @transcoding_sub_protocol.setter
    def transcoding_sub_protocol(self, transcoding_sub_protocol):
        """Sets the transcoding_sub_protocol of this MediaSourceInfo.


        :param transcoding_sub_protocol: The transcoding_sub_protocol of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._transcoding_sub_protocol = transcoding_sub_protocol

    @property
    def transcoding_container(self):
        """Gets the transcoding_container of this MediaSourceInfo.  # noqa: E501


        :return: The transcoding_container of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._transcoding_container

    @transcoding_container.setter
    def transcoding_container(self, transcoding_container):
        """Sets the transcoding_container of this MediaSourceInfo.


        :param transcoding_container: The transcoding_container of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._transcoding_container = transcoding_container

    @property
    def analyze_duration_ms(self):
        """Gets the analyze_duration_ms of this MediaSourceInfo.  # noqa: E501


        :return: The analyze_duration_ms of this MediaSourceInfo.  # noqa: E501
        :rtype: int
        """
        return self._analyze_duration_ms

    @analyze_duration_ms.setter
    def analyze_duration_ms(self, analyze_duration_ms):
        """Sets the analyze_duration_ms of this MediaSourceInfo.


        :param analyze_duration_ms: The analyze_duration_ms of this MediaSourceInfo.  # noqa: E501
        :type: int
        """

        self._analyze_duration_ms = analyze_duration_ms

    @property
    def read_at_native_framerate(self):
        """Gets the read_at_native_framerate of this MediaSourceInfo.  # noqa: E501


        :return: The read_at_native_framerate of this MediaSourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._read_at_native_framerate

    @read_at_native_framerate.setter
    def read_at_native_framerate(self, read_at_native_framerate):
        """Sets the read_at_native_framerate of this MediaSourceInfo.


        :param read_at_native_framerate: The read_at_native_framerate of this MediaSourceInfo.  # noqa: E501
        :type: bool
        """

        self._read_at_native_framerate = read_at_native_framerate

    @property
    def default_audio_stream_index(self):
        """Gets the default_audio_stream_index of this MediaSourceInfo.  # noqa: E501


        :return: The default_audio_stream_index of this MediaSourceInfo.  # noqa: E501
        :rtype: int
        """
        return self._default_audio_stream_index

    @default_audio_stream_index.setter
    def default_audio_stream_index(self, default_audio_stream_index):
        """Sets the default_audio_stream_index of this MediaSourceInfo.


        :param default_audio_stream_index: The default_audio_stream_index of this MediaSourceInfo.  # noqa: E501
        :type: int
        """

        self._default_audio_stream_index = default_audio_stream_index

    @property
    def default_subtitle_stream_index(self):
        """Gets the default_subtitle_stream_index of this MediaSourceInfo.  # noqa: E501


        :return: The default_subtitle_stream_index of this MediaSourceInfo.  # noqa: E501
        :rtype: int
        """
        return self._default_subtitle_stream_index

    @default_subtitle_stream_index.setter
    def default_subtitle_stream_index(self, default_subtitle_stream_index):
        """Sets the default_subtitle_stream_index of this MediaSourceInfo.


        :param default_subtitle_stream_index: The default_subtitle_stream_index of this MediaSourceInfo.  # noqa: E501
        :type: int
        """

        self._default_subtitle_stream_index = default_subtitle_stream_index

    @property
    def item_id(self):
        """Gets the item_id of this MediaSourceInfo.  # noqa: E501

        Used only by our Windows app. Not used by Emby Server. The id of the item that this mediasource belongs to, if there is one Also used by Emby for Kodi  # noqa: E501

        :return: The item_id of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this MediaSourceInfo.

        Used only by our Windows app. Not used by Emby Server. The id of the item that this mediasource belongs to, if there is one Also used by Emby for Kodi  # noqa: E501

        :param item_id: The item_id of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def server_id(self):
        """Gets the server_id of this MediaSourceInfo.  # noqa: E501

        Used only by our Windows app. Not used by Emby Server.  # noqa: E501

        :return: The server_id of this MediaSourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this MediaSourceInfo.

        Used only by our Windows app. Not used by Emby Server.  # noqa: E501

        :param server_id: The server_id of this MediaSourceInfo.  # noqa: E501
        :type: str
        """

        self._server_id = server_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MediaSourceInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MediaSourceInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class SubtitleProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'format': 'str',
        'method': 'SubtitleDeliveryMethod',
        'didl_mode': 'str',
        'language': 'str',
        'container': 'str',
        'protocol': 'str'
    }

    attribute_map = {
        'format': 'Format',
        'method': 'Method',
        'didl_mode': 'DidlMode',
        'language': 'Language',
        'container': 'Container',
        'protocol': 'Protocol'
    }

    def __init__(self, format=None, method=None, didl_mode=None, language=None, container=None, protocol=None):  # noqa: E501
        """SubtitleProfile - a model defined in Swagger"""  # noqa: E501
        self._format = None
        self._method = None
        self._didl_mode = None
        self._language = None
        self._container = None
        self._protocol = None
        self.discriminator = None
        if format is not None:
            self.format = format
        if method is not None:
            self.method = method
        if didl_mode is not None:
            self.didl_mode = didl_mode
        if language is not None:
            self.language = language
        if container is not None:
            self.container = container
        if protocol is not None:
            self.protocol = protocol

    @property
    def format(self):
        """Gets the format of this SubtitleProfile.  # noqa: E501


        :return: The format of this SubtitleProfile.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this SubtitleProfile.


        :param format: The format of this SubtitleProfile.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def method(self):
        """Gets the method of this SubtitleProfile.  # noqa: E501


        :return: The method of this SubtitleProfile.  # noqa: E501
        :rtype: SubtitleDeliveryMethod
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this SubtitleProfile.


        :param method: The method of this SubtitleProfile.  # noqa: E501
        :type: SubtitleDeliveryMethod
        """

        self._method = method

    @property
    def didl_mode(self):
        """Gets the didl_mode of this SubtitleProfile.  # noqa: E501


        :return: The didl_mode of this SubtitleProfile.  # noqa: E501
        :rtype: str
        """
        return self._didl_mode

    @didl_mode.setter
    def didl_mode(self, didl_mode):
        """Sets the didl_mode of this SubtitleProfile.


        :param didl_mode: The didl_mode of this SubtitleProfile.  # noqa: E501
        :type: str
        """

        self._didl_mode = didl_mode

    @property
    def language(self):
        """Gets the language of this SubtitleProfile.  # noqa: E501


        :return: The language of this SubtitleProfile.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this SubtitleProfile.


        :param language: The language of this SubtitleProfile.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def container(self):
        """Gets the container of this SubtitleProfile.  # noqa: E501


        :return: The container of this SubtitleProfile.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this SubtitleProfile.


        :param container: The container of this SubtitleProfile.  # noqa: E501
        :type: str
        """

        self._container = container

    @property
    def protocol(self):
        """Gets the protocol of this SubtitleProfile.  # noqa: E501


        :return: The protocol of this SubtitleProfile.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this SubtitleProfile.


        :param protocol: The protocol of this SubtitleProfile.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SubtitleProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubtitleProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class CodecProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'CodecType',
        'conditions': 'list[ProfileCondition]',
        'apply_conditions': 'list[ProfileCondition]',
        'codec': 'str',
        'container': 'str'
    }

    attribute_map = {
        'type': 'Type',
        'conditions': 'Conditions',
        'apply_conditions': 'ApplyConditions',
        'codec': 'Codec',
        'container': 'Container'
    }

    def __init__(self, type=None, conditions=None, apply_conditions=None, codec=None, container=None):  # noqa: E501
        """CodecProfile - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._conditions = None
        self._apply_conditions = None
        self._codec = None
        self._container = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if conditions is not None:
            self.conditions = conditions
        if apply_conditions is not None:
            self.apply_conditions = apply_conditions
        if codec is not None:
            self.codec = codec
        if container is not None:
            self.container = container

    @property
    def type(self):
        """Gets the type of this CodecProfile.  # noqa: E501


        :return: The type of this CodecProfile.  # noqa: E501
        :rtype: CodecType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CodecProfile.


        :param type: The type of this CodecProfile.  # noqa: E501
        :type: CodecType
        """

        self._type = type

    @property
    def conditions(self):
        """Gets the conditions of this CodecProfile.  # noqa: E501


        :return: The conditions of this CodecProfile.  # noqa: E501
        :rtype: list[ProfileCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this CodecProfile.


        :param conditions: The conditions of this CodecProfile.  # noqa: E501
        :type: list[ProfileCondition]
        """

        self._conditions = conditions

    @property
    def apply_conditions(self):
        """Gets the apply_conditions of this CodecProfile.  # noqa: E501


        :return: The apply_conditions of this CodecProfile.  # noqa: E501
        :rtype: list[ProfileCondition]
        """
        return self._apply_conditions

    @apply_conditions.setter
    def apply_conditions(self, apply_conditions):
        """Sets the apply_conditions of this CodecProfile.


        :param apply_conditions: The apply_conditions of this CodecProfile.  # noqa: E501
        :type: list[ProfileCondition]
        """

        self._apply_conditions = apply_conditions

    @property
    def codec(self):
        """Gets the codec of this CodecProfile.  # noqa: E501


        :return: The codec of this CodecProfile.  # noqa: E501
        :rtype: str
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        """Sets the codec of this CodecProfile.


        :param codec: The codec of this CodecProfile.  # noqa: E501
        :type: str
        """

        self._codec = codec

    @property
    def container(self):
        """Gets the container of this CodecProfile.  # noqa: E501


        :return: The container of this CodecProfile.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this CodecProfile.


        :param container: The container of this CodecProfile.  # noqa: E501
        :type: str
        """

        self._container = container

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CodecProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodecProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class SystemInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'system_update_level': 'PackageVersionClass',
        'operating_system_display_name': 'str',
        'package_name': 'str',
        'has_pending_restart': 'bool',
        'is_shutting_down': 'bool',
        'has_image_enhancers': 'bool',
        'operating_system': 'str',
        'supports_library_monitor': 'bool',
        'supports_local_port_configuration': 'bool',
        'supports_wake_server': 'bool',
        'web_socket_port_number': 'int',
        'completed_installations': 'list[InstallationInfo]',
        'can_self_restart': 'bool',
        'can_self_update': 'bool',
        'can_launch_web_browser': 'bool',
        'program_data_path': 'str',
        'items_by_name_path': 'str',
        'cache_path': 'str',
        'log_path': 'str',
        'internal_metadata_path': 'str',
        'transcoding_temp_path': 'str',
        'http_server_port_number': 'int',
        'supports_https': 'bool',
        'https_port_number': 'int',
        'has_update_available': 'bool',
        'supports_auto_run_at_startup': 'bool',
        'hardware_acceleration_requires_premiere': 'bool',
        'wake_on_lan_info': 'list[WakeOnLanInfo]',
        'local_address': 'str',
        'local_addresses': 'list[str]',
        'wan_address': 'str',
        'remote_addresses': 'list[str]',
        'server_name': 'str',
        'version': 'str',
        'id': 'str'
    }

    attribute_map = {
        'system_update_level': 'SystemUpdateLevel',
        'operating_system_display_name': 'OperatingSystemDisplayName',
        'package_name': 'PackageName',
        'has_pending_restart': 'HasPendingRestart',
        'is_shutting_down': 'IsShuttingDown',
        'has_image_enhancers': 'HasImageEnhancers',
        'operating_system': 'OperatingSystem',
        'supports_library_monitor': 'SupportsLibraryMonitor',
        'supports_local_port_configuration': 'SupportsLocalPortConfiguration',
        'supports_wake_server': 'SupportsWakeServer',
        'web_socket_port_number': 'WebSocketPortNumber',
        'completed_installations': 'CompletedInstallations',
        'can_self_restart': 'CanSelfRestart',
        'can_self_update': 'CanSelfUpdate',
        'can_launch_web_browser': 'CanLaunchWebBrowser',
        'program_data_path': 'ProgramDataPath',
        'items_by_name_path': 'ItemsByNamePath',
        'cache_path': 'CachePath',
        'log_path': 'LogPath',
        'internal_metadata_path': 'InternalMetadataPath',
        'transcoding_temp_path': 'TranscodingTempPath',
        'http_server_port_number': 'HttpServerPortNumber',
        'supports_https': 'SupportsHttps',
        'https_port_number': 'HttpsPortNumber',
        'has_update_available': 'HasUpdateAvailable',
        'supports_auto_run_at_startup': 'SupportsAutoRunAtStartup',
        'hardware_acceleration_requires_premiere': 'HardwareAccelerationRequiresPremiere',
        'wake_on_lan_info': 'WakeOnLanInfo',
        'local_address': 'LocalAddress',
        'local_addresses': 'LocalAddresses',
        'wan_address': 'WanAddress',
        'remote_addresses': 'RemoteAddresses',
        'server_name': 'ServerName',
        'version': 'Version',
        'id': 'Id'
    }

    def __init__(self, system_update_level=None, operating_system_display_name=None, package_name=None, has_pending_restart=None, is_shutting_down=None, has_image_enhancers=None, operating_system=None, supports_library_monitor=None, supports_local_port_configuration=None, supports_wake_server=None, web_socket_port_number=None, completed_installations=None, can_self_restart=None, can_self_update=None, can_launch_web_browser=None, program_data_path=None, items_by_name_path=None, cache_path=None, log_path=None, internal_metadata_path=None, transcoding_temp_path=None, http_server_port_number=None, supports_https=None, https_port_number=None, has_update_available=None, supports_auto_run_at_startup=None, hardware_acceleration_requires_premiere=None, wake_on_lan_info=None, local_address=None, local_addresses=None, wan_address=None, remote_addresses=None, server_name=None, version=None, id=None):  # noqa: E501
        """SystemInfo - a model defined in Swagger"""  # noqa: E501
        self._system_update_level = None
        self._operating_system_display_name = None
        self._package_name = None
        self._has_pending_restart = None
        self._is_shutting_down = None
        self._has_image_enhancers = None
        self._operating_system = None
        self._supports_library_monitor = None
        self._supports_local_port_configuration = None
        self._supports_wake_server = None
        self._web_socket_port_number = None
        self._completed_installations = None
        self._can_self_restart = None
        self._can_self_update = None
        self._can_launch_web_browser = None
        self._program_data_path = None
        self._items_by_name_path = None
        self._cache_path = None
        self._log_path = None
        self._internal_metadata_path = None
        self._transcoding_temp_path = None
        self._http_server_port_number = None
        self._supports_https = None
        self._https_port_number = None
        self._has_update_available = None
        self._supports_auto_run_at_startup = None
        self._hardware_acceleration_requires_premiere = None
        self._wake_on_lan_info = None
        self._local_address = None
        self._local_addresses = None
        self._wan_address = None
        self._remote_addresses = None
        self._server_name = None
        self._version = None
        self._id = None
        self.discriminator = None
        if system_update_level is not None:
            self.system_update_level = system_update_level
        if operating_system_display_name is not None:
            self.operating_system_display_name = operating_system_display_name
        if package_name is not None:
            self.package_name = package_name
        if has_pending_restart is not None:
            self.has_pending_restart = has_pending_restart
        if is_shutting_down is not None:
            self.is_shutting_down = is_shutting_down
        if has_image_enhancers is not None:
            self.has_image_enhancers = has_image_enhancers
        if operating_system is not None:
            self.operating_system = operating_system
        if supports_library_monitor is not None:
            self.supports_library_monitor = supports_library_monitor
        if supports_local_port_configuration is not None:
            self.supports_local_port_configuration = supports_local_port_configuration
        if supports_wake_server is not None:
            self.supports_wake_server = supports_wake_server
        if web_socket_port_number is not None:
            self.web_socket_port_number = web_socket_port_number
        if completed_installations is not None:
            self.completed_installations = completed_installations
        if can_self_restart is not None:
            self.can_self_restart = can_self_restart
        if can_self_update is not None:
            self.can_self_update = can_self_update
        if can_launch_web_browser is not None:
            self.can_launch_web_browser = can_launch_web_browser
        if program_data_path is not None:
            self.program_data_path = program_data_path
        if items_by_name_path is not None:
            self.items_by_name_path = items_by_name_path
        if cache_path is not None:
            self.cache_path = cache_path
        if log_path is not None:
            self.log_path = log_path
        if internal_metadata_path is not None:
            self.internal_metadata_path = internal_metadata_path
        if transcoding_temp_path is not None:
            self.transcoding_temp_path = transcoding_temp_path
        if http_server_port_number is not None:
            self.http_server_port_number = http_server_port_number
        if supports_https is not None:
            self.supports_https = supports_https
        if https_port_number is not None:
            self.https_port_number = https_port_number
        if has_update_available is not None:
            self.has_update_available = has_update_available
        if supports_auto_run_at_startup is not None:
            self.supports_auto_run_at_startup = supports_auto_run_at_startup
        if hardware_acceleration_requires_premiere is not None:
            self.hardware_acceleration_requires_premiere = hardware_acceleration_requires_premiere
        if wake_on_lan_info is not None:
            self.wake_on_lan_info = wake_on_lan_info
        if local_address is not None:
            self.local_address = local_address
        if local_addresses is not None:
            self.local_addresses = local_addresses
        if wan_address is not None:
            self.wan_address = wan_address
        if remote_addresses is not None:
            self.remote_addresses = remote_addresses
        if server_name is not None:
            self.server_name = server_name
        if version is not None:
            self.version = version
        if id is not None:
            self.id = id

    @property
    def system_update_level(self):
        """Gets the system_update_level of this SystemInfo.  # noqa: E501


        :return: The system_update_level of this SystemInfo.  # noqa: E501
        :rtype: PackageVersionClass
        """
        return self._system_update_level

    @system_update_level.setter
    def system_update_level(self, system_update_level):
        """Sets the system_update_level of this SystemInfo.


        :param system_update_level: The system_update_level of this SystemInfo.  # noqa: E501
        :type: PackageVersionClass
        """

        self._system_update_level = system_update_level

    @property
    def operating_system_display_name(self):
        """Gets the operating_system_display_name of this SystemInfo.  # noqa: E501

        The display name of the operating system.  # noqa: E501

        :return: The operating_system_display_name of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._operating_system_display_name

    @operating_system_display_name.setter
    def operating_system_display_name(self, operating_system_display_name):
        """Sets the operating_system_display_name of this SystemInfo.

        The display name of the operating system.  # noqa: E501

        :param operating_system_display_name: The operating_system_display_name of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._operating_system_display_name = operating_system_display_name

    @property
    def package_name(self):
        """Gets the package_name of this SystemInfo.  # noqa: E501


        :return: The package_name of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._package_name

    @package_name.setter
    def package_name(self, package_name):
        """Sets the package_name of this SystemInfo.


        :param package_name: The package_name of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._package_name = package_name

    @property
    def has_pending_restart(self):
        """Gets the has_pending_restart of this SystemInfo.  # noqa: E501

        A value indicating whether this instance has pending restart.  # noqa: E501

        :return: The has_pending_restart of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_pending_restart

    @has_pending_restart.setter
    def has_pending_restart(self, has_pending_restart):
        """Sets the has_pending_restart of this SystemInfo.

        A value indicating whether this instance has pending restart.  # noqa: E501

        :param has_pending_restart: The has_pending_restart of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._has_pending_restart = has_pending_restart

    @property
    def is_shutting_down(self):
        """Gets the is_shutting_down of this SystemInfo.  # noqa: E501


        :return: The is_shutting_down of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_shutting_down

    @is_shutting_down.setter
    def is_shutting_down(self, is_shutting_down):
        """Sets the is_shutting_down of this SystemInfo.


        :param is_shutting_down: The is_shutting_down of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._is_shutting_down = is_shutting_down

    @property
    def has_image_enhancers(self):
        """Gets the has_image_enhancers of this SystemInfo.  # noqa: E501


        :return: The has_image_enhancers of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_image_enhancers

    @has_image_enhancers.setter
    def has_image_enhancers(self, has_image_enhancers):
        """Sets the has_image_enhancers of this SystemInfo.


        :param has_image_enhancers: The has_image_enhancers of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._has_image_enhancers = has_image_enhancers

    @property
    def operating_system(self):
        """Gets the operating_system of this SystemInfo.  # noqa: E501

        The operating sytem.  # noqa: E501

        :return: The operating_system of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._operating_system

    @operating_system.setter
    def operating_system(self, operating_system):
        """Sets the operating_system of this SystemInfo.

        The operating sytem.  # noqa: E501

        :param operating_system: The operating_system of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._operating_system = operating_system

    @property
    def supports_library_monitor(self):
        """Gets the supports_library_monitor of this SystemInfo.  # noqa: E501

        A value indicating whether \\[supports library monitor\\].  # noqa: E501

        :return: The supports_library_monitor of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supports_library_monitor

    @supports_library_monitor.setter
    def supports_library_monitor(self, supports_library_monitor):
        """Sets the supports_library_monitor of this SystemInfo.

        A value indicating whether \\[supports library monitor\\].  # noqa: E501

        :param supports_library_monitor: The supports_library_monitor of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._supports_library_monitor = supports_library_monitor

    @property
    def supports_local_port_configuration(self):
        """Gets the supports_local_port_configuration of this SystemInfo.  # noqa: E501


        :return: The supports_local_port_configuration of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supports_local_port_configuration

    @supports_local_port_configuration.setter
    def supports_local_port_configuration(self, supports_local_port_configuration):
        """Sets the supports_local_port_configuration of this SystemInfo.


        :param supports_local_port_configuration: The supports_local_port_configuration of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._supports_local_port_configuration = supports_local_port_configuration

    @property
    def supports_wake_server(self):
        """Gets the supports_wake_server of this SystemInfo.  # noqa: E501


        :return: The supports_wake_server of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supports_wake_server

    @supports_wake_server.setter
    def supports_wake_server(self, supports_wake_server):
        """Sets the supports_wake_server of this SystemInfo.


        :param supports_wake_server: The supports_wake_server of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._supports_wake_server = supports_wake_server

    @property
    def web_socket_port_number(self):
        """Gets the web_socket_port_number of this SystemInfo.  # noqa: E501

        The web socket port number.  # noqa: E501

        :return: The web_socket_port_number of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._web_socket_port_number

    @web_socket_port_number.setter
    def web_socket_port_number(self, web_socket_port_number):
        """Sets the web_socket_port_number of this SystemInfo.

        The web socket port number.  # noqa: E501

        :param web_socket_port_number: The web_socket_port_number of this SystemInfo.  # noqa: E501
        :type: int
        """

        self._web_socket_port_number = web_socket_port_number

    @property
    def completed_installations(self):
        """Gets the completed_installations of this SystemInfo.  # noqa: E501

        The completed installations.  # noqa: E501

        :return: The completed_installations of this SystemInfo.  # noqa: E501
        :rtype: list[InstallationInfo]
        """
        return self._completed_installations

    @completed_installations.setter
    def completed_installations(self, completed_installations):
        """Sets the completed_installations of this SystemInfo.

        The completed installations.  # noqa: E501

        :param completed_installations: The completed_installations of this SystemInfo.  # noqa: E501
        :type: list[InstallationInfo]
        """

        self._completed_installations = completed_installations

    @property
    def can_self_restart(self):
        """Gets the can_self_restart of this SystemInfo.  # noqa: E501

        A value indicating whether this instance can self restart.  # noqa: E501

        :return: The can_self_restart of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_self_restart

    @can_self_restart.setter
    def can_self_restart(self, can_self_restart):
        """Sets the can_self_restart of this SystemInfo.

        A value indicating whether this instance can self restart.  # noqa: E501

        :param can_self_restart: The can_self_restart of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._can_self_restart = can_self_restart

    @property
    def can_self_update(self):
        """Gets the can_self_update of this SystemInfo.  # noqa: E501

        A value indicating whether this instance can self update.  # noqa: E501

        :return: The can_self_update of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_self_update

    @can_self_update.setter
    def can_self_update(self, can_self_update):
        """Sets the can_self_update of this SystemInfo.

        A value indicating whether this instance can self update.  # noqa: E501

        :param can_self_update: The can_self_update of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._can_self_update = can_self_update

    @property
    def can_launch_web_browser(self):
        """Gets the can_launch_web_browser of this SystemInfo.  # noqa: E501


        :return: The can_launch_web_browser of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_launch_web_browser

    @can_launch_web_browser.setter
    def can_launch_web_browser(self, can_launch_web_browser):
        """Sets the can_launch_web_browser of this SystemInfo.


        :param can_launch_web_browser: The can_launch_web_browser of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._can_launch_web_browser = can_launch_web_browser

    @property
    def program_data_path(self):
        """Gets the program_data_path of this SystemInfo.  # noqa: E501

        The program data path.  # noqa: E501

        :return: The program_data_path of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._program_data_path

    @program_data_path.setter
    def program_data_path(self, program_data_path):
        """Sets the program_data_path of this SystemInfo.

        The program data path.  # noqa: E501

        :param program_data_path: The program_data_path of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._program_data_path = program_data_path

    @property
    def items_by_name_path(self):
        """Gets the items_by_name_path of this SystemInfo.  # noqa: E501

        The items by name path.  # noqa: E501

        :return: The items_by_name_path of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._items_by_name_path

    @items_by_name_path.setter
    def items_by_name_path(self, items_by_name_path):
        """Sets the items_by_name_path of this SystemInfo.

        The items by name path.  # noqa: E501

        :param items_by_name_path: The items_by_name_path of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._items_by_name_path = items_by_name_path

    @property
    def cache_path(self):
        """Gets the cache_path of this SystemInfo.  # noqa: E501

        The cache path.  # noqa: E501

        :return: The cache_path of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._cache_path

    @cache_path.setter
    def cache_path(self, cache_path):
        """Sets the cache_path of this SystemInfo.

        The cache path.  # noqa: E501

        :param cache_path: The cache_path of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._cache_path = cache_path

    @property
    def log_path(self):
        """Gets the log_path of this SystemInfo.  # noqa: E501

        The log path.  # noqa: E501

        :return: The log_path of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._log_path

    @log_path.setter
    def log_path(self, log_path):
        """Sets the log_path of this SystemInfo.

        The log path.  # noqa: E501

        :param log_path: The log_path of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._log_path = log_path

    @property
    def internal_metadata_path(self):
        """Gets the internal_metadata_path of this SystemInfo.  # noqa: E501

        The internal metadata path.  # noqa: E501

        :return: The internal_metadata_path of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._internal_metadata_path

    @internal_metadata_path.setter
    def internal_metadata_path(self, internal_metadata_path):
        """Sets the internal_metadata_path of this SystemInfo.

        The internal metadata path.  # noqa: E501

        :param internal_metadata_path: The internal_metadata_path of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._internal_metadata_path = internal_metadata_path

    @property
    def transcoding_temp_path(self):
        """Gets the transcoding_temp_path of this SystemInfo.  # noqa: E501

        The transcoding temporary path.  # noqa: E501

        :return: The transcoding_temp_path of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._transcoding_temp_path

    @transcoding_temp_path.setter
    def transcoding_temp_path(self, transcoding_temp_path):
        """Sets the transcoding_temp_path of this SystemInfo.

        The transcoding temporary path.  # noqa: E501

        :param transcoding_temp_path: The transcoding_temp_path of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._transcoding_temp_path = transcoding_temp_path

    @property
    def http_server_port_number(self):
        """Gets the http_server_port_number of this SystemInfo.  # noqa: E501

        The HTTP server port number.  # noqa: E501

        :return: The http_server_port_number of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._http_server_port_number

    @http_server_port_number.setter
    def http_server_port_number(self, http_server_port_number):
        """Sets the http_server_port_number of this SystemInfo.

        The HTTP server port number.  # noqa: E501

        :param http_server_port_number: The http_server_port_number of this SystemInfo.  # noqa: E501
        :type: int
        """

        self._http_server_port_number = http_server_port_number

    @property
    def supports_https(self):
        """Gets the supports_https of this SystemInfo.  # noqa: E501

        A value indicating whether \\[enable HTTPS\\].  # noqa: E501

        :return: The supports_https of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supports_https

    @supports_https.setter
    def supports_https(self, supports_https):
        """Sets the supports_https of this SystemInfo.

        A value indicating whether \\[enable HTTPS\\].  # noqa: E501

        :param supports_https: The supports_https of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._supports_https = supports_https

    @property
    def https_port_number(self):
        """Gets the https_port_number of this SystemInfo.  # noqa: E501

        The HTTPS server port number.  # noqa: E501

        :return: The https_port_number of this SystemInfo.  # noqa: E501
        :rtype: int
        """
        return self._https_port_number

    @https_port_number.setter
    def https_port_number(self, https_port_number):
        """Sets the https_port_number of this SystemInfo.

        The HTTPS server port number.  # noqa: E501

        :param https_port_number: The https_port_number of this SystemInfo.  # noqa: E501
        :type: int
        """

        self._https_port_number = https_port_number

    @property
    def has_update_available(self):
        """Gets the has_update_available of this SystemInfo.  # noqa: E501

        A value indicating whether this instance has update available.  # noqa: E501

        :return: The has_update_available of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_update_available

    @has_update_available.setter
    def has_update_available(self, has_update_available):
        """Sets the has_update_available of this SystemInfo.

        A value indicating whether this instance has update available.  # noqa: E501

        :param has_update_available: The has_update_available of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._has_update_available = has_update_available

    @property
    def supports_auto_run_at_startup(self):
        """Gets the supports_auto_run_at_startup of this SystemInfo.  # noqa: E501

        A value indicating whether \\[supports automatic run at startup\\].  # noqa: E501

        :return: The supports_auto_run_at_startup of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._supports_auto_run_at_startup

    @supports_auto_run_at_startup.setter
    def supports_auto_run_at_startup(self, supports_auto_run_at_startup):
        """Sets the supports_auto_run_at_startup of this SystemInfo.

        A value indicating whether \\[supports automatic run at startup\\].  # noqa: E501

        :param supports_auto_run_at_startup: The supports_auto_run_at_startup of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._supports_auto_run_at_startup = supports_auto_run_at_startup

    @property
    def hardware_acceleration_requires_premiere(self):
        """Gets the hardware_acceleration_requires_premiere of this SystemInfo.  # noqa: E501


        :return: The hardware_acceleration_requires_premiere of this SystemInfo.  # noqa: E501
        :rtype: bool
        """
        return self._hardware_acceleration_requires_premiere

    @hardware_acceleration_requires_premiere.setter
    def hardware_acceleration_requires_premiere(self, hardware_acceleration_requires_premiere):
        """Sets the hardware_acceleration_requires_premiere of this SystemInfo.


        :param hardware_acceleration_requires_premiere: The hardware_acceleration_requires_premiere of this SystemInfo.  # noqa: E501
        :type: bool
        """

        self._hardware_acceleration_requires_premiere = hardware_acceleration_requires_premiere

    @property
    def wake_on_lan_info(self):
        """Gets the wake_on_lan_info of this SystemInfo.  # noqa: E501


        :return: The wake_on_lan_info of this SystemInfo.  # noqa: E501
        :rtype: list[WakeOnLanInfo]
        """
        return self._wake_on_lan_info

    @wake_on_lan_info.setter
    def wake_on_lan_info(self, wake_on_lan_info):
        """Sets the wake_on_lan_info of this SystemInfo.


        :param wake_on_lan_info: The wake_on_lan_info of this SystemInfo.  # noqa: E501
        :type: list[WakeOnLanInfo]
        """

        self._wake_on_lan_info = wake_on_lan_info

    @property
    def local_address(self):
        """Gets the local_address of this SystemInfo.  # noqa: E501

        The local address.  # noqa: E501

        :return: The local_address of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._local_address

    @local_address.setter
    def local_address(self, local_address):
        """Sets the local_address of this SystemInfo.

        The local address.  # noqa: E501

        :param local_address: The local_address of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._local_address = local_address

    @property
    def local_addresses(self):
        """Gets the local_addresses of this SystemInfo.  # noqa: E501


        :return: The local_addresses of this SystemInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._local_addresses

    @local_addresses.setter
    def local_addresses(self, local_addresses):
        """Sets the local_addresses of this SystemInfo.


        :param local_addresses: The local_addresses of this SystemInfo.  # noqa: E501
        :type: list[str]
        """

        self._local_addresses = local_addresses

    @property
    def wan_address(self):
        """Gets the wan_address of this SystemInfo.  # noqa: E501

        The wan address.  # noqa: E501

        :return: The wan_address of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._wan_address

    @wan_address.setter
    def wan_address(self, wan_address):
        """Sets the wan_address of this SystemInfo.

        The wan address.  # noqa: E501

        :param wan_address: The wan_address of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._wan_address = wan_address

    @property
    def remote_addresses(self):
        """Gets the remote_addresses of this SystemInfo.  # noqa: E501


        :return: The remote_addresses of this SystemInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._remote_addresses

    @remote_addresses.setter
    def remote_addresses(self, remote_addresses):
        """Sets the remote_addresses of this SystemInfo.


        :param remote_addresses: The remote_addresses of this SystemInfo.  # noqa: E501
        :type: list[str]
        """

        self._remote_addresses = remote_addresses

    @property
    def server_name(self):
        """Gets the server_name of this SystemInfo.  # noqa: E501

        The name of the server.  # noqa: E501

        :return: The server_name of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._server_name

    @server_name.setter
    def server_name(self, server_name):
        """Sets the server_name of this SystemInfo.

        The name of the server.  # noqa: E501

        :param server_name: The server_name of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._server_name = server_name

    @property
    def version(self):
        """Gets the version of this SystemInfo.  # noqa: E501

        The version.  # noqa: E501

        :return: The version of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SystemInfo.

        The version.  # noqa: E501

        :param version: The version of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def id(self):
        """Gets the id of this SystemInfo.  # noqa: E501

        The id.  # noqa: E501

        :return: The id of this SystemInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SystemInfo.

        The id.  # noqa: E501

        :param id: The id of this SystemInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SystemInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class PlaylistServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_playlists_by_id_items(self, id, entry_ids, **kwargs):  # noqa: E501
        """Removes items from a playlist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_playlists_by_id_items(id, entry_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str entry_ids: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_playlists_by_id_items_with_http_info(id, entry_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_playlists_by_id_items_with_http_info(id, entry_ids, **kwargs)  # noqa: E501
            return data

    def delete_playlists_by_id_items_with_http_info(self, id, entry_ids, **kwargs):  # noqa: E501
        """Removes items from a playlist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_playlists_by_id_items_with_http_info(id, entry_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str entry_ids: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'entry_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_playlists_by_id_items" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_playlists_by_id_items`")  # noqa: E501
        # verify the required parameter 'entry_ids' is set
        if ('entry_ids' not in params or
                params['entry_ids'] is None):
            raise ValueError("Missing the required parameter `entry_ids` when calling `delete_playlists_by_id_items`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'entry_ids' in params:
            query_params.append(('EntryIds', params['entry_ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Playlists/{Id}/Items', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_playlists_by_id_addtoplaylistinfo(self, ids, id, **kwargs):  # noqa: E501
        """Gets add to playlist info  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_playlists_by_id_addtoplaylistinfo(ids, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ids: Item id, comma delimited (required)
        :param str id: (required)
        :param str user_id: User Id
        :return: PlaylistsAddToPlaylistInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_playlists_by_id_addtoplaylistinfo_with_http_info(ids, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_playlists_by_id_addtoplaylistinfo_with_http_info(ids, id, **kwargs)  # noqa: E501
            return data

    def get_playlists_by_id_addtoplaylistinfo_with_http_info(self, ids, id, **kwargs):  # noqa: E501
        """Gets add to playlist info  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_playlists_by_id_addtoplaylistinfo_with_http_info(ids, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ids: Item id, comma delimited (required)
        :param str id: (required)
        :param str user_id: User Id
        :return: PlaylistsAddToPlaylistInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ids', 'id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_playlists_by_id_addtoplaylistinfo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ids' is set
        if ('ids' not in params or
                params['ids'] is None):
            raise ValueError("Missing the required parameter `ids` when calling `get_playlists_by_id_addtoplaylistinfo`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_playlists_by_id_addtoplaylistinfo`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'user_id' in params:
            query_params.append(('UserId', params['user_id']))  # noqa: E501
        if 'ids' in params:
            query_params.append(('Ids', params['ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Playlists/{Id}/AddToPlaylistInfo', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlaylistsAddToPlaylistInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_playlists_by_id_items(self, id, **kwargs):  # noqa: E501
        """Gets the original items of a playlist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_playlists_by_id_items(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str user_id: User Id
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines
        :param bool enable_images: Optional, include image information in output
        :param bool enable_user_data: Optional, include user data
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_playlists_by_id_items_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_playlists_by_id_items_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_playlists_by_id_items_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets the original items of a playlist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_playlists_by_id_items_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str user_id: User Id
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines
        :param bool enable_images: Optional, include image information in output
        :param bool enable_user_data: Optional, include user data
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'user_id', 'start_index', 'limit', 'fields', 'enable_images', 'enable_user_data', 'image_type_limit', 'enable_image_types']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_playlists_by_id_items" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_playlists_by_id_items`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'user_id' in params:
            query_params.append(('UserId', params['user_id']))  # noqa: E501
        if 'start_index' in params:
            query_params.append(('StartIndex', params['start_index']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('Limit', params['limit']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('Fields', params['fields']))  # noqa: E501
        if 'enable_images' in params:
            query_params.append(('EnableImages', params['enable_images']))  # noqa: E501
        if 'enable_user_data' in params:
            query_params.append(('EnableUserData', params['enable_user_data']))  # noqa: E501
        if 'image_type_limit' in params:
            query_params.append(('ImageTypeLimit', params['image_type_limit']))  # noqa: E501
        if 'enable_image_types' in params:
            query_params.append(('EnableImageTypes', params['enable_image_types']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Playlists/{Id}/Items', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultBaseItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_playlists(self, **kwargs):  # noqa: E501
        """Creates a new playlist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_playlists(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The name of the new playlist.
        :param str ids: Item Ids to add to the playlist
        :param str media_type: The playlist media type
        :return: PlaylistsPlaylistCreationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_playlists_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_playlists_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_playlists_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a new playlist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_playlists_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The name of the new playlist.
        :param str ids: Item Ids to add to the playlist
        :param str media_type: The playlist media type
        :return: PlaylistsPlaylistCreationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'ids', 'media_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_playlists" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in params:
            query_params.append(('Name', params['name']))  # noqa: E501
        if 'ids' in params:
            query_params.append(('Ids', params['ids']))  # noqa: E501
        if 'media_type' in params:
            query_params.append(('MediaType', params['media_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Playlists', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlaylistsPlaylistCreationResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_playlists_by_id_items(self, ids, id, **kwargs):  # noqa: E501
        """Adds items to a playlist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_playlists_by_id_items(ids, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ids: Item id, comma delimited (required)
        :param str id: (required)
        :param str user_id: User Id
        :return: PlaylistsAddToPlaylistResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_playlists_by_id_items_with_http_info(ids, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_playlists_by_id_items_with_http_info(ids, id, **kwargs)  # noqa: E501
            return data

    def post_playlists_by_id_items_with_http_info(self, ids, id, **kwargs):  # noqa: E501
        """Adds items to a playlist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_playlists_by_id_items_with_http_info(ids, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ids: Item id, comma delimited (required)
        :param str id: (required)
        :param str user_id: User Id
        :return: PlaylistsAddToPlaylistResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ids', 'id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_playlists_by_id_items" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ids' is set
        if ('ids' not in params or
                params['ids'] is None):
            raise ValueError("Missing the required parameter `ids` when calling `post_playlists_by_id_items`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_playlists_by_id_items`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'user_id' in params:
            query_params.append(('UserId', params['user_id']))  # noqa: E501
        if 'ids' in params:
            query_params.append(('Ids', params['ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Playlists/{Id}/Items', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlaylistsAddToPlaylistResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_playlists_by_id_items_by_itemid_move_by_newindex(self, item_id, id, new_index, **kwargs):  # noqa: E501
        """Moves a playlist item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_playlists_by_id_items_by_itemid_move_by_newindex(item_id, id, new_index, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int item_id: ItemId (required)
        :param str id: (required)
        :param int new_index: NewIndex (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_playlists_by_id_items_by_itemid_move_by_newindex_with_http_info(item_id, id, new_index, **kwargs)  # noqa: E501
        else:
            (data) = self.post_playlists_by_id_items_by_itemid_move_by_newindex_with_http_info(item_id, id, new_index, **kwargs)  # noqa: E501
            return data

    def post_playlists_by_id_items_by_itemid_move_by_newindex_with_http_info(self, item_id, id, new_index, **kwargs):  # noqa: E501
        """Moves a playlist item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_playlists_by_id_items_by_itemid_move_by_newindex_with_http_info(item_id, id, new_index, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int item_id: ItemId (required)
        :param str id: (required)
        :param int new_index: NewIndex (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['item_id', 'id', 'new_index']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_playlists_by_id_items_by_itemid_move_by_newindex" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'item_id' is set
        if ('item_id' not in params or
                params['item_id'] is None):
            raise ValueError("Missing the required parameter `item_id` when calling `post_playlists_by_id_items_by_itemid_move_by_newindex`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_playlists_by_id_items_by_itemid_move_by_newindex`")  # noqa: E501
        # verify the required parameter 'new_index' is set
        if ('new_index' not in params or
                params['new_index'] is None):
            raise ValueError("Missing the required parameter `new_index` when calling `post_playlists_by_id_items_by_itemid_move_by_newindex`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'item_id' in params:
            path_params['ItemId'] = params['item_id']  # noqa: E501
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501
        if 'new_index' in params:
            path_params['NewIndex'] = params['new_index']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Playlists/{Id}/Items/{ItemId}/Move/{NewIndex}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_playlists_by_id_items_delete(self, id, entry_ids, **kwargs):  # noqa: E501
        """Removes items from a playlist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_playlists_by_id_items_delete(id, entry_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str entry_ids: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_playlists_by_id_items_delete_with_http_info(id, entry_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.post_playlists_by_id_items_delete_with_http_info(id, entry_ids, **kwargs)  # noqa: E501
            return data

    def post_playlists_by_id_items_delete_with_http_info(self, id, entry_ids, **kwargs):  # noqa: E501
        """Removes items from a playlist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_playlists_by_id_items_delete_with_http_info(id, entry_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str entry_ids: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'entry_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_playlists_by_id_items_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_playlists_by_id_items_delete`")  # noqa: E501
        # verify the required parameter 'entry_ids' is set
        if ('entry_ids' not in params or
                params['entry_ids'] is None):
            raise ValueError("Missing the required parameter `entry_ids` when calling `post_playlists_by_id_items_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'entry_ids' in params:
            query_params.append(('EntryIds', params['entry_ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Playlists/{Id}/Items/Delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

# import apis into sdk package
from emby_client.api.activity_log_service_api import ActivityLogServiceApi
from emby_client.api.artists_service_api import ArtistsServiceApi
from emby_client.api.audio_service_api import AudioServiceApi
from emby_client.api.backup_api_api import BackupApiApi
from emby_client.api.bif_service_api import BifServiceApi
from emby_client.api.branding_service_api import BrandingServiceApi
from emby_client.api.channel_service_api import ChannelServiceApi
from emby_client.api.codec_parameter_service_api import CodecParameterServiceApi
from emby_client.api.collection_service_api import CollectionServiceApi
from emby_client.api.configuration_service_api import ConfigurationServiceApi
from emby_client.api.connect_service_api import ConnectServiceApi
from emby_client.api.device_service_api import DeviceServiceApi
from emby_client.api.display_preferences_service_api import DisplayPreferencesServiceApi
from emby_client.api.dlna_server_service_api import DlnaServerServiceApi
from emby_client.api.dlna_service_api import DlnaServiceApi
from emby_client.api.dynamic_hls_service_api import DynamicHlsServiceApi
from emby_client.api.encoding_info_service_api import EncodingInfoServiceApi
from emby_client.api.environment_service_api import EnvironmentServiceApi
from emby_client.api.feature_service_api import FeatureServiceApi
from emby_client.api.ffmpeg_options_service_api import FfmpegOptionsServiceApi
from emby_client.api.game_genres_service_api import GameGenresServiceApi
from emby_client.api.generic_ui_api_service_api import GenericUIApiServiceApi
from emby_client.api.genres_service_api import GenresServiceApi
from emby_client.api.hls_segment_service_api import HlsSegmentServiceApi
from emby_client.api.image_service_api import ImageServiceApi
from emby_client.api.instant_mix_service_api import InstantMixServiceApi
from emby_client.api.item_lookup_service_api import ItemLookupServiceApi
from emby_client.api.item_refresh_service_api import ItemRefreshServiceApi
from emby_client.api.item_update_service_api import ItemUpdateServiceApi
from emby_client.api.items_service_api import ItemsServiceApi
from emby_client.api.library_service_api import LibraryServiceApi
from emby_client.api.library_structure_service_api import LibraryStructureServiceApi
from emby_client.api.live_stream_service_api import LiveStreamServiceApi
from emby_client.api.live_tv_service_api import LiveTvServiceApi
from emby_client.api.localization_service_api import LocalizationServiceApi
from emby_client.api.media_info_service_api import MediaInfoServiceApi
from emby_client.api.movies_service_api import MoviesServiceApi
from emby_client.api.music_genres_service_api import MusicGenresServiceApi
from emby_client.api.notifications_service_api import NotificationsServiceApi
from emby_client.api.official_rating_service_api import OfficialRatingServiceApi
from emby_client.api.open_api_service_api import OpenApiServiceApi
from emby_client.api.package_service_api import PackageServiceApi
from emby_client.api.persons_service_api import PersonsServiceApi
from emby_client.api.playlist_service_api import PlaylistServiceApi
from emby_client.api.playstate_service_api import PlaystateServiceApi
from emby_client.api.plugin_service_api import PluginServiceApi
from emby_client.api.remote_image_service_api import RemoteImageServiceApi
from emby_client.api.scheduled_task_service_api import ScheduledTaskServiceApi
from emby_client.api.sessions_service_api import SessionsServiceApi
from emby_client.api.studios_service_api import StudiosServiceApi
from emby_client.api.subtitle_options_service_api import SubtitleOptionsServiceApi
from emby_client.api.subtitle_service_api import SubtitleServiceApi
from emby_client.api.suggestions_service_api import SuggestionsServiceApi
from emby_client.api.sync_service_api import SyncServiceApi
from emby_client.api.system_service_api import SystemServiceApi
from emby_client.api.tag_service_api import TagServiceApi
from emby_client.api.tone_map_options_service_api import ToneMapOptionsServiceApi
from emby_client.api.trailers_service_api import TrailersServiceApi
from emby_client.api.tv_shows_service_api import TvShowsServiceApi
from emby_client.api.universal_audio_service_api import UniversalAudioServiceApi
from emby_client.api.user_library_service_api import UserLibraryServiceApi
from emby_client.api.user_notifications_service_api import UserNotificationsServiceApi
from emby_client.api.user_service_api import UserServiceApi
from emby_client.api.user_views_service_api import UserViewsServiceApi
from emby_client.api.video_hls_service_api import VideoHlsServiceApi
from emby_client.api.video_service_api import VideoServiceApi
from emby_client.api.videos_service_api import VideosServiceApi
from emby_client.api.web_app_service_api import WebAppServiceApi
# import ApiClient
from emby_client.api_client import ApiClient
from emby_client.configuration import Configuration
# import models into sdk package
from emby_client.models.access_schedule import AccessSchedule
from emby_client.models.actions_postback_action import ActionsPostbackAction
from emby_client.models.activity_log_entry import ActivityLogEntry
from emby_client.models.album_info import AlbumInfo
from emby_client.models.all_theme_media_result import AllThemeMediaResult
from emby_client.models.api_available_recording_options import ApiAvailableRecordingOptions
from emby_client.models.api_base_items_request import ApiBaseItemsRequest
from emby_client.models.api_configuration_page_info import ApiConfigurationPageInfo
from emby_client.models.api_epg_row import ApiEpgRow
from emby_client.models.api_listing_provider_type_info import ApiListingProviderTypeInfo
from emby_client.models.api_name_id_description_pair import ApiNameIdDescriptionPair
from emby_client.models.api_on_playback_progress import ApiOnPlaybackProgress
from emby_client.models.api_set_channel_disabled import ApiSetChannelDisabled
from emby_client.models.api_set_channel_mapping import ApiSetChannelMapping
from emby_client.models.api_set_channel_sort_index import ApiSetChannelSortIndex
from emby_client.models.api_tag_item import ApiTagItem
from emby_client.models.artist_info import ArtistInfo
from emby_client.models.attributes_simple_condition import AttributesSimpleCondition
from emby_client.models.attributes_value_condition import AttributesValueCondition
from emby_client.models.authenticate_user import AuthenticateUser
from emby_client.models.authenticate_user_by_name import AuthenticateUserByName
from emby_client.models.authentication_authentication_result import AuthenticationAuthenticationResult
from emby_client.models.base_item_dto import BaseItemDto
from emby_client.models.base_item_person import BaseItemPerson
from emby_client.models.bit_rate import BitRate
from emby_client.models.book_info import BookInfo
from emby_client.models.branding_branding_options import BrandingBrandingOptions
from emby_client.models.channel_management_info import ChannelManagementInfo
from emby_client.models.chapter_info import ChapterInfo
from emby_client.models.client_capabilities import ClientCapabilities
from emby_client.models.codec_configuration import CodecConfiguration
from emby_client.models.codec_directions import CodecDirections
from emby_client.models.codec_kinds import CodecKinds
from emby_client.models.codec_profile import CodecProfile
from emby_client.models.codec_type import CodecType
from emby_client.models.collections_collection_creation_result import CollectionsCollectionCreationResult
from emby_client.models.color_formats import ColorFormats
from emby_client.models.common_editor_types import CommonEditorTypes
from emby_client.models.common_interfaces_i_codec_device_capabilities import CommonInterfacesICodecDeviceCapabilities
from emby_client.models.common_interfaces_i_codec_device_info import CommonInterfacesICodecDeviceInfo
from emby_client.models.common_plugins_i_plugin import CommonPluginsIPlugin
from emby_client.models.conditions_property_condition import ConditionsPropertyCondition
from emby_client.models.conditions_property_condition_type import ConditionsPropertyConditionType
from emby_client.models.configuration_tone_mapping_tone_map_options_visibility import ConfigurationToneMappingToneMapOptionsVisibility
from emby_client.models.connect_connect_authentication_exchange_result import ConnectConnectAuthenticationExchangeResult
from emby_client.models.connect_user_link_result import ConnectUserLinkResult
from emby_client.models.connect_user_link_type import ConnectUserLinkType
from emby_client.models.container_profile import ContainerProfile
from emby_client.models.create_user_by_name import CreateUserByName
from emby_client.models.day_of_week import DayOfWeek
from emby_client.models.default_directory_browser_info import DefaultDirectoryBrowserInfo
from emby_client.models.device_profile import DeviceProfile
from emby_client.models.devices_content_upload_history import DevicesContentUploadHistory
from emby_client.models.devices_device_info import DevicesDeviceInfo
from emby_client.models.devices_device_options import DevicesDeviceOptions
from emby_client.models.devices_local_file_info import DevicesLocalFileInfo
from emby_client.models.direct_play_profile import DirectPlayProfile
from emby_client.models.display_preferences import DisplayPreferences
from emby_client.models.dlna_profile_type import DlnaProfileType
from emby_client.models.dlna_profiles_device_identification import DlnaProfilesDeviceIdentification
from emby_client.models.dlna_profiles_device_profile_type import DlnaProfilesDeviceProfileType
from emby_client.models.dlna_profiles_dlna_profile import DlnaProfilesDlnaProfile
from emby_client.models.dlna_profiles_header_match_type import DlnaProfilesHeaderMatchType
from emby_client.models.dlna_profiles_http_header_info import DlnaProfilesHttpHeaderInfo
from emby_client.models.dlna_profiles_protocol_info_detection import DlnaProfilesProtocolInfoDetection
from emby_client.models.drawing_image_orientation import DrawingImageOrientation
from emby_client.models.dynamic_day_of_week import DynamicDayOfWeek
from emby_client.models.edit_object_container import EditObjectContainer
from emby_client.models.editors_editor_base import EditorsEditorBase
from emby_client.models.editors_editor_button_item import EditorsEditorButtonItem
from emby_client.models.editors_editor_root import EditorsEditorRoot
from emby_client.models.encoding_context import EncodingContext
from emby_client.models.enums_ui_command_type import EnumsUICommandType
from emby_client.models.enums_ui_view_type import EnumsUIViewType
from emby_client.models.extended_video_sub_types import ExtendedVideoSubTypes
from emby_client.models.extended_video_types import ExtendedVideoTypes
from emby_client.models.external_id_info import ExternalIdInfo
from emby_client.models.external_url import ExternalUrl
from emby_client.models.feature_info import FeatureInfo
from emby_client.models.feature_type import FeatureType
from emby_client.models.forgot_password import ForgotPassword
from emby_client.models.forgot_password_action import ForgotPasswordAction
from emby_client.models.forgot_password_pin import ForgotPasswordPin
from emby_client.models.forgot_password_result import ForgotPasswordResult
from emby_client.models.game_info import GameInfo
from emby_client.models.general_command import GeneralCommand
from emby_client.models.generic_edit_i_edit_object_container import GenericEditIEditObjectContainer
from emby_client.models.get_directory_contents import GetDirectoryContents
from emby_client.models.globalization_country_info import GlobalizationCountryInfo
from emby_client.models.globalization_culture_dto import GlobalizationCultureDto
from emby_client.models.globalization_localizaton_option import GlobalizationLocalizatonOption
from emby_client.models.io_file_system_entry_info import IOFileSystemEntryInfo
from emby_client.models.io_file_system_entry_type import IOFileSystemEntryType
from emby_client.models.image_info import ImageInfo
from emby_client.models.image_option import ImageOption
from emby_client.models.image_provider_info import ImageProviderInfo
from emby_client.models.image_saving_convention import ImageSavingConvention
from emby_client.models.image_type import ImageType
from emby_client.models.images_base_download_remote_image import ImagesBaseDownloadRemoteImage
from emby_client.models.installation_info import InstallationInfo
from emby_client.models.item_counts import ItemCounts
from emby_client.models.item_file_info import ItemFileInfo
from emby_client.models.item_file_type import ItemFileType
from emby_client.models.item_lookup_info import ItemLookupInfo
from emby_client.models.level_information import LevelInformation
from emby_client.models.library_add_media_path import LibraryAddMediaPath
from emby_client.models.library_add_virtual_folder import LibraryAddVirtualFolder
from emby_client.models.library_delete_info import LibraryDeleteInfo
from emby_client.models.library_item_link_type import LibraryItemLinkType
from emby_client.models.library_media_folder import LibraryMediaFolder
from emby_client.models.library_media_update_info import LibraryMediaUpdateInfo
from emby_client.models.library_option_info import LibraryOptionInfo
from emby_client.models.library_options import LibraryOptions
from emby_client.models.library_options_result import LibraryOptionsResult
from emby_client.models.library_post_updated_media import LibraryPostUpdatedMedia
from emby_client.models.library_remove_media_path import LibraryRemoveMediaPath
from emby_client.models.library_remove_virtual_folder import LibraryRemoveVirtualFolder
from emby_client.models.library_rename_virtual_folder import LibraryRenameVirtualFolder
from emby_client.models.library_sub_folder import LibrarySubFolder
from emby_client.models.library_type_options import LibraryTypeOptions
from emby_client.models.library_update_library_options import LibraryUpdateLibraryOptions
from emby_client.models.library_update_media_path import LibraryUpdateMediaPath
from emby_client.models.library_user_copy_options import LibraryUserCopyOptions
from emby_client.models.live_stream_request import LiveStreamRequest
from emby_client.models.live_stream_response import LiveStreamResponse
from emby_client.models.live_tv_channel_type import LiveTvChannelType
from emby_client.models.live_tv_guide_info import LiveTvGuideInfo
from emby_client.models.live_tv_keep_until import LiveTvKeepUntil
from emby_client.models.live_tv_keyword_info import LiveTvKeywordInfo
from emby_client.models.live_tv_keyword_type import LiveTvKeywordType
from emby_client.models.live_tv_listings_provider_info import LiveTvListingsProviderInfo
from emby_client.models.live_tv_live_tv_info import LiveTvLiveTvInfo
from emby_client.models.live_tv_recording_status import LiveTvRecordingStatus
from emby_client.models.live_tv_series_timer_info import LiveTvSeriesTimerInfo
from emby_client.models.live_tv_series_timer_info_dto import LiveTvSeriesTimerInfoDto
from emby_client.models.live_tv_timer_info_dto import LiveTvTimerInfoDto
from emby_client.models.live_tv_timer_type import LiveTvTimerType
from emby_client.models.live_tv_tuner_host_info import LiveTvTunerHostInfo
from emby_client.models.location_type import LocationType
from emby_client.models.log_file import LogFile
from emby_client.models.logging_log_severity import LoggingLogSeverity
from emby_client.models.mb_backup_api_all_backups_info import MBBackupApiAllBackupsInfo
from emby_client.models.mb_backup_api_data_restore_options import MBBackupApiDataRestoreOptions
from emby_client.models.mb_backup_api_restore_options import MBBackupApiRestoreOptions
from emby_client.models.mb_backup_api_user_restore_info import MBBackupApiUserRestoreInfo
from emby_client.models.mb_backup_backup_info import MBBackupBackupInfo
from emby_client.models.marker_type import MarkerType
from emby_client.models.media_encoding_codec_parameter_context import MediaEncodingCodecParameterContext
from emby_client.models.media_path_info import MediaPathInfo
from emby_client.models.media_protocol import MediaProtocol
from emby_client.models.media_source_info import MediaSourceInfo
from emby_client.models.media_source_type import MediaSourceType
from emby_client.models.media_stream import MediaStream
from emby_client.models.media_stream_type import MediaStreamType
from emby_client.models.media_url import MediaUrl
from emby_client.models.metadata_editor_info import MetadataEditorInfo
from emby_client.models.metadata_features import MetadataFeatures
from emby_client.models.metadata_fields import MetadataFields
from emby_client.models.metadata_refresh_mode import MetadataRefreshMode
from emby_client.models.movie_info import MovieInfo
from emby_client.models.music_video_info import MusicVideoInfo
from emby_client.models.name_id_pair import NameIdPair
from emby_client.models.name_long_id_pair import NameLongIdPair
from emby_client.models.name_value_pair import NameValuePair
from emby_client.models.net_end_point_info import NetEndPointInfo
from emby_client.models.net_sockets_address_family import NetSocketsAddressFamily
from emby_client.models.notification_category_info import NotificationCategoryInfo
from emby_client.models.notification_type_info import NotificationTypeInfo
from emby_client.models.operating_system import OperatingSystem
from emby_client.models.package_info import PackageInfo
from emby_client.models.package_target_system import PackageTargetSystem
from emby_client.models.package_version_class import PackageVersionClass
from emby_client.models.package_version_info import PackageVersionInfo
from emby_client.models.parental_rating import ParentalRating
from emby_client.models.path_substitution import PathSubstitution
from emby_client.models.persistence_intro_debug_info import PersistenceIntroDebugInfo
from emby_client.models.person_lookup_info import PersonLookupInfo
from emby_client.models.person_type import PersonType
from emby_client.models.pin_redeem_result import PinRedeemResult
from emby_client.models.play_command import PlayCommand
from emby_client.models.play_method import PlayMethod
from emby_client.models.play_request import PlayRequest
from emby_client.models.playback_error_code import PlaybackErrorCode
from emby_client.models.playback_info_request import PlaybackInfoRequest
from emby_client.models.playback_info_response import PlaybackInfoResponse
from emby_client.models.playback_progress_info import PlaybackProgressInfo
from emby_client.models.playback_start_info import PlaybackStartInfo
from emby_client.models.playback_stop_info import PlaybackStopInfo
from emby_client.models.player_state_info import PlayerStateInfo
from emby_client.models.playlists_add_to_playlist_info import PlaylistsAddToPlaylistInfo
from emby_client.models.playlists_add_to_playlist_result import PlaylistsAddToPlaylistResult
from emby_client.models.playlists_playlist_creation_result import PlaylistsPlaylistCreationResult
from emby_client.models.playstate_command import PlaystateCommand
from emby_client.models.playstate_request import PlaystateRequest
from emby_client.models.plugins_configuration_page_type import PluginsConfigurationPageType
from emby_client.models.plugins_plugin_info import PluginsPluginInfo
from emby_client.models.process_run_metrics_process_metric_point import ProcessRunMetricsProcessMetricPoint
from emby_client.models.process_run_metrics_process_statistics import ProcessRunMetricsProcessStatistics
from emby_client.models.profile_condition import ProfileCondition
from emby_client.models.profile_condition_type import ProfileConditionType
from emby_client.models.profile_condition_value import ProfileConditionValue
from emby_client.models.profile_information import ProfileInformation
from emby_client.models.profile_level_information import ProfileLevelInformation
from emby_client.models.progress_event import ProgressEvent
from emby_client.models.provider_id_dictionary import ProviderIdDictionary
from emby_client.models.proxy_header_mode import ProxyHeaderMode
from emby_client.models.public_system_info import PublicSystemInfo
from emby_client.models.query_result_activity_log_entry import QueryResultActivityLogEntry
from emby_client.models.query_result_api_epg_row import QueryResultApiEpgRow
from emby_client.models.query_result_base_item_dto import QueryResultBaseItemDto
from emby_client.models.query_result_channel_management_info import QueryResultChannelManagementInfo
from emby_client.models.query_result_devices_device_info import QueryResultDevicesDeviceInfo
from emby_client.models.query_result_live_tv_series_timer_info_dto import QueryResultLiveTvSeriesTimerInfoDto
from emby_client.models.query_result_live_tv_timer_info_dto import QueryResultLiveTvTimerInfoDto
from emby_client.models.query_result_log_file import QueryResultLogFile
from emby_client.models.query_result_string import QueryResultString
from emby_client.models.query_result_sync_job import QueryResultSyncJob
from emby_client.models.query_result_sync_job_item import QueryResultSyncJobItem
from emby_client.models.query_result_user_dto import QueryResultUserDto
from emby_client.models.query_result_user_library_official_rating_item import QueryResultUserLibraryOfficialRatingItem
from emby_client.models.query_result_user_library_tag_item import QueryResultUserLibraryTagItem
from emby_client.models.query_result_virtual_folder_info import QueryResultVirtualFolderInfo
from emby_client.models.queue_item import QueueItem
from emby_client.models.rating_type import RatingType
from emby_client.models.recommendation_dto import RecommendationDto
from emby_client.models.recommendation_type import RecommendationType
from emby_client.models.remote_image_info import RemoteImageInfo
from emby_client.models.remote_image_result import RemoteImageResult
from emby_client.models.remote_search_query_album_info import RemoteSearchQueryAlbumInfo
from emby_client.models.remote_search_query_artist_info import RemoteSearchQueryArtistInfo
from emby_client.models.remote_search_query_book_info import RemoteSearchQueryBookInfo
from emby_client.models.remote_search_query_game_info import RemoteSearchQueryGameInfo
from emby_client.models.remote_search_query_item_lookup_info import RemoteSearchQueryItemLookupInfo
from emby_client.models.remote_search_query_movie_info import RemoteSearchQueryMovieInfo
from emby_client.models.remote_search_query_music_video_info import RemoteSearchQueryMusicVideoInfo
from emby_client.models.remote_search_query_person_lookup_info import RemoteSearchQueryPersonLookupInfo
from emby_client.models.remote_search_query_series_info import RemoteSearchQuerySeriesInfo
from emby_client.models.remote_search_query_trailer_info import RemoteSearchQueryTrailerInfo
from emby_client.models.remote_search_result import RemoteSearchResult
from emby_client.models.remote_subtitle_info import RemoteSubtitleInfo
from emby_client.models.repeat_mode import RepeatMode
from emby_client.models.resolution import Resolution
from emby_client.models.resolution_with_rate import ResolutionWithRate
from emby_client.models.response_profile import ResponseProfile
from emby_client.models.roku_metadata_api_thumbnail_info import RokuMetadataApiThumbnailInfo
from emby_client.models.roku_metadata_api_thumbnail_set_info import RokuMetadataApiThumbnailSetInfo
from emby_client.models.run_ui_command import RunUICommand
from emby_client.models.secondary_frameworks import SecondaryFrameworks
from emby_client.models.segment_skip_mode import SegmentSkipMode
from emby_client.models.series_display_order import SeriesDisplayOrder
from emby_client.models.series_info import SeriesInfo
from emby_client.models.server_configuration import ServerConfiguration
from emby_client.models.session_session_info import SessionSessionInfo
from emby_client.models.session_user_info import SessionUserInfo
from emby_client.models.song_info import SongInfo
from emby_client.models.sort_order import SortOrder
from emby_client.models.subtitle_delivery_method import SubtitleDeliveryMethod
from emby_client.models.subtitle_location_type import SubtitleLocationType
from emby_client.models.subtitle_playback_mode import SubtitlePlaybackMode
from emby_client.models.subtitle_profile import SubtitleProfile
from emby_client.models.subtitles_subtitle_download_result import SubtitlesSubtitleDownloadResult
from emby_client.models.sync_category import SyncCategory
from emby_client.models.sync_data_request import SyncDataRequest
from emby_client.models.sync_data_response import SyncDataResponse
from emby_client.models.sync_dialog_options import SyncDialogOptions
from emby_client.models.sync_job import SyncJob
from emby_client.models.sync_job_creation_result import SyncJobCreationResult
from emby_client.models.sync_job_item import SyncJobItem
from emby_client.models.sync_job_item_status import SyncJobItemStatus
from emby_client.models.sync_job_option import SyncJobOption
from emby_client.models.sync_job_request import SyncJobRequest
from emby_client.models.sync_job_status import SyncJobStatus
from emby_client.models.sync_profile_option import SyncProfileOption
from emby_client.models.sync_quality_option import SyncQualityOption
from emby_client.models.sync_target import SyncTarget
from emby_client.models.synced_item import SyncedItem
from emby_client.models.synced_item_progress import SyncedItemProgress
from emby_client.models.system_event import SystemEvent
from emby_client.models.system_info import SystemInfo
from emby_client.models.task_completion_status import TaskCompletionStatus
from emby_client.models.task_info import TaskInfo
from emby_client.models.task_result import TaskResult
from emby_client.models.task_state import TaskState
from emby_client.models.task_trigger_info import TaskTriggerInfo
from emby_client.models.theme_media_result import ThemeMediaResult
from emby_client.models.trailer_info import TrailerInfo
from emby_client.models.transcode_reason import TranscodeReason
from emby_client.models.transcode_seek_info import TranscodeSeekInfo
from emby_client.models.transcoding_info import TranscodingInfo
from emby_client.models.transcoding_profile import TranscodingProfile
from emby_client.models.transcoding_vp_step_info import TranscodingVpStepInfo
from emby_client.models.transcoding_vp_step_types import TranscodingVpStepTypes
from emby_client.models.transport_stream_timestamp import TransportStreamTimestamp
from emby_client.models.tuple_double_double import TupleDoubleDouble
from emby_client.models.type_options import TypeOptions
from emby_client.models.ui_command import UICommand
from emby_client.models.ui_tab_page_info import UITabPageInfo
from emby_client.models.ui_view_info import UIViewInfo
from emby_client.models.unrated_item import UnratedItem
from emby_client.models.update_user_password import UpdateUserPassword
from emby_client.models.user_action import UserAction
from emby_client.models.user_action_type import UserActionType
from emby_client.models.user_configuration import UserConfiguration
from emby_client.models.user_dto import UserDto
from emby_client.models.user_item_data_dto import UserItemDataDto
from emby_client.models.user_item_share_level import UserItemShareLevel
from emby_client.models.user_library_add_tags import UserLibraryAddTags
from emby_client.models.user_library_leave_shared_items import UserLibraryLeaveSharedItems
from emby_client.models.user_library_official_rating_item import UserLibraryOfficialRatingItem
from emby_client.models.user_library_remove_tags import UserLibraryRemoveTags
from emby_client.models.user_library_tag_item import UserLibraryTagItem
from emby_client.models.user_library_update_user_item_access import UserLibraryUpdateUserItemAccess
from emby_client.models.user_notification_info import UserNotificationInfo
from emby_client.models.user_policy import UserPolicy
from emby_client.models.validate_path import ValidatePath
from emby_client.models.version import Version
from emby_client.models.video3_d_format import Video3DFormat
from emby_client.models.video_codec_base import VideoCodecBase
from emby_client.models.video_media_types import VideoMediaTypes
from emby_client.models.virtual_folder_info import VirtualFolderInfo
from emby_client.models.wake_on_lan_info import WakeOnLanInfo



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class CommonInterfacesICodecDeviceInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capabilities': 'CommonInterfacesICodecDeviceCapabilities',
        'adapter': 'int',
        'name': 'str',
        'desription': 'str',
        'driver': 'str',
        'driver_version': 'Version',
        'api_version': 'Version',
        'vendor_id': 'int',
        'device_id': 'int',
        'device_identifier': 'str',
        'hardware_context_framework': 'SecondaryFrameworks',
        'dev_path': 'str',
        'drm_node': 'str',
        'vendor_name': 'str',
        'device_name': 'str'
    }

    attribute_map = {
        'capabilities': 'Capabilities',
        'adapter': 'Adapter',
        'name': 'Name',
        'desription': 'Desription',
        'driver': 'Driver',
        'driver_version': 'DriverVersion',
        'api_version': 'ApiVersion',
        'vendor_id': 'VendorId',
        'device_id': 'DeviceId',
        'device_identifier': 'DeviceIdentifier',
        'hardware_context_framework': 'HardwareContextFramework',
        'dev_path': 'DevPath',
        'drm_node': 'DrmNode',
        'vendor_name': 'VendorName',
        'device_name': 'DeviceName'
    }

    def __init__(self, capabilities=None, adapter=None, name=None, desription=None, driver=None, driver_version=None, api_version=None, vendor_id=None, device_id=None, device_identifier=None, hardware_context_framework=None, dev_path=None, drm_node=None, vendor_name=None, device_name=None):  # noqa: E501
        """CommonInterfacesICodecDeviceInfo - a model defined in Swagger"""  # noqa: E501
        self._capabilities = None
        self._adapter = None
        self._name = None
        self._desription = None
        self._driver = None
        self._driver_version = None
        self._api_version = None
        self._vendor_id = None
        self._device_id = None
        self._device_identifier = None
        self._hardware_context_framework = None
        self._dev_path = None
        self._drm_node = None
        self._vendor_name = None
        self._device_name = None
        self.discriminator = None
        if capabilities is not None:
            self.capabilities = capabilities
        if adapter is not None:
            self.adapter = adapter
        if name is not None:
            self.name = name
        if desription is not None:
            self.desription = desription
        if driver is not None:
            self.driver = driver
        if driver_version is not None:
            self.driver_version = driver_version
        if api_version is not None:
            self.api_version = api_version
        if vendor_id is not None:
            self.vendor_id = vendor_id
        if device_id is not None:
            self.device_id = device_id
        if device_identifier is not None:
            self.device_identifier = device_identifier
        if hardware_context_framework is not None:
            self.hardware_context_framework = hardware_context_framework
        if dev_path is not None:
            self.dev_path = dev_path
        if drm_node is not None:
            self.drm_node = drm_node
        if vendor_name is not None:
            self.vendor_name = vendor_name
        if device_name is not None:
            self.device_name = device_name

    @property
    def capabilities(self):
        """Gets the capabilities of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The capabilities of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: CommonInterfacesICodecDeviceCapabilities
        """
        return self._capabilities

    @capabilities.setter
    def capabilities(self, capabilities):
        """Sets the capabilities of this CommonInterfacesICodecDeviceInfo.


        :param capabilities: The capabilities of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: CommonInterfacesICodecDeviceCapabilities
        """

        self._capabilities = capabilities

    @property
    def adapter(self):
        """Gets the adapter of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The adapter of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: int
        """
        return self._adapter

    @adapter.setter
    def adapter(self, adapter):
        """Sets the adapter of this CommonInterfacesICodecDeviceInfo.


        :param adapter: The adapter of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: int
        """

        self._adapter = adapter

    @property
    def name(self):
        """Gets the name of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The name of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CommonInterfacesICodecDeviceInfo.


        :param name: The name of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def desription(self):
        """Gets the desription of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The desription of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._desription

    @desription.setter
    def desription(self, desription):
        """Sets the desription of this CommonInterfacesICodecDeviceInfo.


        :param desription: The desription of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: str
        """

        self._desription = desription

    @property
    def driver(self):
        """Gets the driver of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The driver of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._driver

    @driver.setter
    def driver(self, driver):
        """Sets the driver of this CommonInterfacesICodecDeviceInfo.


        :param driver: The driver of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: str
        """

        self._driver = driver

    @property
    def driver_version(self):
        """Gets the driver_version of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The driver_version of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: Version
        """
        return self._driver_version

    @driver_version.setter
    def driver_version(self, driver_version):
        """Sets the driver_version of this CommonInterfacesICodecDeviceInfo.


        :param driver_version: The driver_version of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: Version
        """

        self._driver_version = driver_version

    @property
    def api_version(self):
        """Gets the api_version of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The api_version of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: Version
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this CommonInterfacesICodecDeviceInfo.


        :param api_version: The api_version of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: Version
        """

        self._api_version = api_version

    @property
    def vendor_id(self):
        """Gets the vendor_id of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The vendor_id of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: int
        """
        return self._vendor_id

    @vendor_id.setter
    def vendor_id(self, vendor_id):
        """Sets the vendor_id of this CommonInterfacesICodecDeviceInfo.


        :param vendor_id: The vendor_id of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: int
        """

        self._vendor_id = vendor_id

    @property
    def device_id(self):
        """Gets the device_id of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The device_id of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: int
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this CommonInterfacesICodecDeviceInfo.


        :param device_id: The device_id of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: int
        """

        self._device_id = device_id

    @property
    def device_identifier(self):
        """Gets the device_identifier of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The device_identifier of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_identifier

    @device_identifier.setter
    def device_identifier(self, device_identifier):
        """Sets the device_identifier of this CommonInterfacesICodecDeviceInfo.


        :param device_identifier: The device_identifier of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: str
        """

        self._device_identifier = device_identifier

    @property
    def hardware_context_framework(self):
        """Gets the hardware_context_framework of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The hardware_context_framework of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: SecondaryFrameworks
        """
        return self._hardware_context_framework

    @hardware_context_framework.setter
    def hardware_context_framework(self, hardware_context_framework):
        """Sets the hardware_context_framework of this CommonInterfacesICodecDeviceInfo.


        :param hardware_context_framework: The hardware_context_framework of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: SecondaryFrameworks
        """

        self._hardware_context_framework = hardware_context_framework

    @property
    def dev_path(self):
        """Gets the dev_path of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The dev_path of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._dev_path

    @dev_path.setter
    def dev_path(self, dev_path):
        """Sets the dev_path of this CommonInterfacesICodecDeviceInfo.


        :param dev_path: The dev_path of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: str
        """

        self._dev_path = dev_path

    @property
    def drm_node(self):
        """Gets the drm_node of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The drm_node of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._drm_node

    @drm_node.setter
    def drm_node(self, drm_node):
        """Sets the drm_node of this CommonInterfacesICodecDeviceInfo.


        :param drm_node: The drm_node of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: str
        """

        self._drm_node = drm_node

    @property
    def vendor_name(self):
        """Gets the vendor_name of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The vendor_name of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._vendor_name

    @vendor_name.setter
    def vendor_name(self, vendor_name):
        """Sets the vendor_name of this CommonInterfacesICodecDeviceInfo.


        :param vendor_name: The vendor_name of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: str
        """

        self._vendor_name = vendor_name

    @property
    def device_name(self):
        """Gets the device_name of this CommonInterfacesICodecDeviceInfo.  # noqa: E501


        :return: The device_name of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this CommonInterfacesICodecDeviceInfo.


        :param device_name: The device_name of this CommonInterfacesICodecDeviceInfo.  # noqa: E501
        :type: str
        """

        self._device_name = device_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CommonInterfacesICodecDeviceInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommonInterfacesICodecDeviceInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
